/****************************************************************************
** Meta object code from reading C++ file 'Category.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/Category/Category.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Category.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CategoryFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto CategoryFilter::qt_create_metaobjectdata<qt_meta_tag_ZN14CategoryFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CategoryFilter",
        "FilterType",
        "CategoryNameFilter",
        "PkgSectionFilter",
        "PkgWildcardFilter",
        "PkgNameFilter",
        "AppstreamIdWildcardFilter",
        "OrFilter",
        "AndFilter",
        "NotFilter"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FilterType'
        QtMocHelpers::EnumData<enum FilterType>(1, 1, QMC::EnumFlags{}).add({
            {    2, FilterType::CategoryNameFilter },
            {    3, FilterType::PkgSectionFilter },
            {    4, FilterType::PkgWildcardFilter },
            {    5, FilterType::PkgNameFilter },
            {    6, FilterType::AppstreamIdWildcardFilter },
            {    7, FilterType::OrFilter },
            {    8, FilterType::AndFilter },
            {    9, FilterType::NotFilter },
        }),
    };
    return QtMocHelpers::metaObjectData<CategoryFilter, qt_meta_tag_ZN14CategoryFilterE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CategoryFilter::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CategoryFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CategoryFilterE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CategoryFilterE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN8CategoryE_t {};
} // unnamed namespace

template <> constexpr inline auto Category::qt_create_metaobjectdata<qt_meta_tag_ZN8CategoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Category",
        "subCategoriesChanged",
        "",
        "nameChanged",
        "visibleChanged",
        "contains",
        "std::shared_ptr<Category>",
        "cat",
        "QVariantList",
        "cats",
        "name",
        "icon",
        "subcategories",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'subCategoriesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'contains'
        QtMocHelpers::MethodData<bool(const std::shared_ptr<Category> &) const>(5, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'contains'
        QtMocHelpers::MethodData<bool(const QVariantList &) const>(5, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'subcategories'
        QtMocHelpers::PropertyData<QVariantList>(12, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Category, qt_meta_tag_ZN8CategoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Category::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CategoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CategoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8CategoryE_t>.metaTypes,
    nullptr
} };

void Category::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Category *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->subCategoriesChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->visibleChanged(); break;
        case 3: { bool _r = _t->contains((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Category>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->contains((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< std::shared_ptr<Category> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Category::*)()>(_a, &Category::subCategoriesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Category::*)()>(_a, &Category::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Category::*)()>(_a, &Category::visibleChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->subCategoriesVariant(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        default: break;
        }
    }
}

const QMetaObject *Category::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Category::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CategoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Category::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Category::subCategoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Category::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Category::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
