/****************************************************************************
** Meta object code from reading C++ file 'DiscoverNotifier.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/notifier/DiscoverNotifier.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DiscoverNotifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DiscoverNotifierE_t {};
} // unnamed namespace

template <> constexpr inline auto DiscoverNotifier::qt_create_metaobjectdata<qt_meta_tag_ZN16DiscoverNotifierE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiscoverNotifier",
        "stateChanged",
        "",
        "needsRebootChanged",
        "needsReboot",
        "newUpgradeAction",
        "UpgradeAction*",
        "action",
        "busyChanged",
        "recheckSystemUpdateNeededAndNotifyApp",
        "recheckSystemUpdateNeeded",
        "showDiscover",
        "xdgActivationToken",
        "showDiscoverUpdates",
        "showUpdatesNotification",
        "rebootPrompt",
        "shutdownPrompt",
        "promptAll",
        "foundUpgradeAction",
        "modules",
        "iconName",
        "message",
        "state",
        "State",
        "busy",
        "isSystemUpdateable",
        "NoUpdates",
        "NormalUpdates",
        "SecurityUpdates",
        "Busy",
        "RebootRequired",
        "Offline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needsRebootChanged'
        QtMocHelpers::SignalData<bool(bool)>(3, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'newUpgradeAction'
        QtMocHelpers::SignalData<void(UpgradeAction *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<bool()>(8, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'recheckSystemUpdateNeededAndNotifyApp'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'recheckSystemUpdateNeeded'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showDiscover'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'showDiscoverUpdates'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'showUpdatesNotification'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rebootPrompt'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shutdownPrompt'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'promptAll'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'foundUpgradeAction'
        QtMocHelpers::SlotData<void(UpgradeAction *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'modules'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'needsReboot'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'isSystemUpdateable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(23, 23, QMC::EnumFlags{}).add({
            {   26, State::NoUpdates },
            {   27, State::NormalUpdates },
            {   28, State::SecurityUpdates },
            {   29, State::Busy },
            {   30, State::RebootRequired },
            {   31, State::Offline },
        }),
    };
    return QtMocHelpers::metaObjectData<DiscoverNotifier, qt_meta_tag_ZN16DiscoverNotifierE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DiscoverNotifier::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DiscoverNotifierE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DiscoverNotifierE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DiscoverNotifierE_t>.metaTypes,
    nullptr
} };

void DiscoverNotifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiscoverNotifier *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: { bool _r = _t->needsRebootChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->newUpgradeAction((*reinterpret_cast<std::add_pointer_t<UpgradeAction*>>(_a[1]))); break;
        case 3: { bool _r = _t->busyChanged();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->recheckSystemUpdateNeededAndNotifyApp(); break;
        case 5: _t->recheckSystemUpdateNeeded(); break;
        case 6: _t->showDiscover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->showDiscoverUpdates((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->showUpdatesNotification(); break;
        case 9: _t->rebootPrompt(); break;
        case 10: _t->shutdownPrompt(); break;
        case 11: _t->promptAll(); break;
        case 12: _t->foundUpgradeAction((*reinterpret_cast<std::add_pointer_t<UpgradeAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UpgradeAction* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UpgradeAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiscoverNotifier::*)()>(_a, &DiscoverNotifier::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<bool (DiscoverNotifier::*)(bool )>(_a, &DiscoverNotifier::needsRebootChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverNotifier::*)(UpgradeAction * )>(_a, &DiscoverNotifier::newUpgradeAction, 2))
            return;
        if (QtMocHelpers::indexOfMethod<bool (DiscoverNotifier::*)()>(_a, &DiscoverNotifier::busyChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->loadedModules(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 3: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->needsReboot(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isSystemUpdateable(); break;
        default: break;
        }
    }
}

const QMetaObject *DiscoverNotifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiscoverNotifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DiscoverNotifierE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DiscoverNotifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DiscoverNotifier::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
bool DiscoverNotifier::needsRebootChanged(bool _t1)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 1, std::addressof(_t0), _t1);
    return _t0;
}

// SIGNAL 2
void DiscoverNotifier::newUpgradeAction(UpgradeAction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
bool DiscoverNotifier::busyChanged()
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 3, std::addressof(_t0));
    return _t0;
}
QT_WARNING_POP
