/****************************************************************************
** Meta object code from reading C++ file 'FlatpakResource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/FlatpakBackend/FlatpakResource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FlatpakResource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15FlatpakResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakResource::qt_create_metaobjectdata<qt_meta_tag_ZN15FlatpakResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakResource",
        "hasDataChanged",
        "",
        "propertyStateChanged",
        "FlatpakResource::PropertyKind",
        "kind",
        "FlatpakResource::PropertyState",
        "state",
        "eolReasonChanged",
        "permissionsModel",
        "QAbstractListModel*",
        "clearUserData",
        "versionCompare",
        "FlatpakResource*",
        "resource",
        "attentionText",
        "dataLocation",
        "branch",
        "isDesktopApp",
        "eolReason",
        "hasData",
        "ref",
        "PropertyKind",
        "DownloadSize",
        "InstalledSize",
        "RequiredRuntime",
        "PropertyState",
        "NotKnownYet",
        "AlreadyKnown",
        "UnknownOrFailed",
        "Fetching",
        "ResourceType",
        "DesktopApp",
        "Runtime",
        "Extension",
        "Source",
        "FlatpakFileType",
        "NotAFile",
        "FileFlatpak",
        "FileFlatpakRef"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hasDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyStateChanged'
        QtMocHelpers::SignalData<void(FlatpakResource::PropertyKind, FlatpakResource::PropertyState)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'eolReasonChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'permissionsModel'
        QtMocHelpers::MethodData<QAbstractListModel *()>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Method 'clearUserData'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'versionCompare'
        QtMocHelpers::MethodData<int(FlatpakResource *) const>(12, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'attentionText'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dataLocation'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'branch'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isDesktopApp'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'eolReason'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'hasData'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'ref'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PropertyKind'
        QtMocHelpers::EnumData<enum PropertyKind>(22, 22, QMC::EnumFlags{}).add({
            {   23, PropertyKind::DownloadSize },
            {   24, PropertyKind::InstalledSize },
            {   25, PropertyKind::RequiredRuntime },
        }),
        // enum 'PropertyState'
        QtMocHelpers::EnumData<enum PropertyState>(26, 26, QMC::EnumFlags{}).add({
            {   27, PropertyState::NotKnownYet },
            {   28, PropertyState::AlreadyKnown },
            {   29, PropertyState::UnknownOrFailed },
            {   30, PropertyState::Fetching },
        }),
        // enum 'ResourceType'
        QtMocHelpers::EnumData<enum ResourceType>(31, 31, QMC::EnumFlags{}).add({
            {   32, ResourceType::DesktopApp },
            {   33, ResourceType::Runtime },
            {   34, ResourceType::Extension },
            {   35, ResourceType::Source },
        }),
        // enum 'FlatpakFileType'
        QtMocHelpers::EnumData<enum FlatpakFileType>(36, 36, QMC::EnumFlags{}).add({
            {   37, FlatpakFileType::NotAFile },
            {   38, FlatpakFileType::FileFlatpak },
            {   39, FlatpakFileType::FileFlatpakRef },
        }),
    };
    return QtMocHelpers::metaObjectData<FlatpakResource, qt_meta_tag_ZN15FlatpakResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakResource::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractResource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FlatpakResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FlatpakResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15FlatpakResourceE_t>.metaTypes,
    nullptr
} };

void FlatpakResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlatpakResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hasDataChanged(); break;
        case 1: _t->propertyStateChanged((*reinterpret_cast<std::add_pointer_t<FlatpakResource::PropertyKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FlatpakResource::PropertyState>>(_a[2]))); break;
        case 2: _t->eolReasonChanged(); break;
        case 3: { QAbstractListModel* _r = _t->permissionsModel();
            if (_a[0]) *reinterpret_cast<QAbstractListModel**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->clearUserData(); break;
        case 5: { int _r = _t->versionCompare((*reinterpret_cast<std::add_pointer_t<FlatpakResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FlatpakResource* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FlatpakResource::*)()>(_a, &FlatpakResource::hasDataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakResource::*)(FlatpakResource::PropertyKind , FlatpakResource::PropertyState )>(_a, &FlatpakResource::propertyStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakResource::*)()>(_a, &FlatpakResource::eolReasonChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->attentionText(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->dataLocation(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->branch(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDesktopApp(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->eolReason(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasData(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->ref(); break;
        default: break;
        }
    }
}

const QMetaObject *FlatpakResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlatpakResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FlatpakResourceE_t>.strings))
        return static_cast<void*>(this);
    return AbstractResource::qt_metacast(_clname);
}

int FlatpakResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractResource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void FlatpakResource::hasDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FlatpakResource::propertyStateChanged(FlatpakResource::PropertyKind _t1, FlatpakResource::PropertyState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void FlatpakResource::eolReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
