/****************************************************************************
** Meta object code from reading C++ file 'TransactionListener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/Transaction/TransactionListener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TransactionListener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TransactionListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto TransactionListener::qt_create_metaobjectdata<qt_meta_tag_ZN19TransactionListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransactionListener",
        "resourceChanged",
        "",
        "cancellableChanged",
        "isActiveChanged",
        "statusTextChanged",
        "cancelled",
        "progressChanged",
        "transactionChanged",
        "Transaction*",
        "transaction",
        "transactionAdded",
        "trans",
        "transactionStatusChanged",
        "Transaction::Status",
        "status",
        "cancel",
        "resource",
        "AbstractResource*",
        "isCancellable",
        "isActive",
        "statusText",
        "progress"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resourceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancellableChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isActiveChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusTextChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancelled'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transactionChanged'
        QtMocHelpers::SignalData<void(Transaction *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'transactionAdded'
        QtMocHelpers::SlotData<void(Transaction *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'transactionStatusChanged'
        QtMocHelpers::SlotData<void(Transaction::Status)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'cancel'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resource'
        QtMocHelpers::PropertyData<AbstractResource*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'transaction'
        QtMocHelpers::PropertyData<Transaction*>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'isCancellable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isActive'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'statusText'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'progress'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransactionListener, qt_meta_tag_ZN19TransactionListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransactionListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransactionListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransactionListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TransactionListenerE_t>.metaTypes,
    nullptr
} };

void TransactionListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransactionListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resourceChanged(); break;
        case 1: _t->cancellableChanged(); break;
        case 2: _t->isActiveChanged(); break;
        case 3: _t->statusTextChanged(); break;
        case 4: _t->cancelled(); break;
        case 5: _t->progressChanged(); break;
        case 6: _t->transactionChanged((*reinterpret_cast<std::add_pointer_t<Transaction*>>(_a[1]))); break;
        case 7: _t->transactionAdded((*reinterpret_cast<std::add_pointer_t<Transaction*>>(_a[1]))); break;
        case 8: _t->transactionStatusChanged((*reinterpret_cast<std::add_pointer_t<Transaction::Status>>(_a[1]))); break;
        case 9: _t->cancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transaction* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transaction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::resourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::cancellableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::isActiveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::statusTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::cancelled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)()>(_a, &TransactionListener::progressChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionListener::*)(Transaction * )>(_a, &TransactionListener::transactionChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transaction* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AbstractResource**>(_v) = _t->resource(); break;
        case 1: *reinterpret_cast<Transaction**>(_v) = _t->transaction(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isCancellable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->statusText(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->progress(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResource(*reinterpret_cast<AbstractResource**>(_v)); break;
        case 1: _t->setTransaction(*reinterpret_cast<Transaction**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TransactionListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransactionListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransactionListenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TransactionListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TransactionListener::resourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TransactionListener::cancellableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TransactionListener::isActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TransactionListener::statusTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TransactionListener::cancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TransactionListener::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TransactionListener::transactionChanged(Transaction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
