/****************************************************************************
** Meta object code from reading C++ file 'ResourcesModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/ResourcesModel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ResourcesModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AggregatedResultsStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto AggregatedResultsStream::qt_create_metaobjectdata<qt_meta_tag_ZN23AggregatedResultsStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AggregatedResultsStream",
        "finished",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AggregatedResultsStream, qt_meta_tag_ZN23AggregatedResultsStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AggregatedResultsStream::staticMetaObject = { {
    QMetaObject::SuperData::link<ResultsStream::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AggregatedResultsStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AggregatedResultsStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AggregatedResultsStreamE_t>.metaTypes,
    nullptr
} };

void AggregatedResultsStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AggregatedResultsStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AggregatedResultsStream::*)()>(_a, &AggregatedResultsStream::finished, 0))
            return;
    }
}

const QMetaObject *AggregatedResultsStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AggregatedResultsStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AggregatedResultsStreamE_t>.strings))
        return static_cast<void*>(this);
    return ResultsStream::qt_metacast(_clname);
}

int AggregatedResultsStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ResultsStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void AggregatedResultsStream::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN14ResourcesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourcesModel::qt_create_metaobjectdata<qt_meta_tag_ZN14ResourcesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourcesModel",
        "fetchingChanged",
        "",
        "isFetching",
        "backendsChanged",
        "updatesCountChanged",
        "updatesCount",
        "backendDataChanged",
        "AbstractResourcesBackend*",
        "backend",
        "QList<QByteArray>",
        "properties",
        "resourceDataChanged",
        "AbstractResource*",
        "resource",
        "resourceRemoved",
        "passiveMessage",
        "message",
        "currentApplicationBackendChanged",
        "currentApplicationBackend",
        "fetchingUpdatesProgressChanged",
        "fetchingUpdatesProgress",
        "inlineMessageChanged",
        "QSharedPointer<InlineMessage>",
        "inlineMessage",
        "switchToUpdates",
        "installApplication",
        "app",
        "AddonList",
        "addons",
        "removeApplication",
        "callerContentsChanged",
        "updateCaller",
        "registerAllBackends",
        "isExtended",
        "id",
        "distroBugReportUrl",
        "QUrl",
        "hasSecurityUpdates",
        "updateAction",
        "DiscoverAction*",
        "remainingDescription",
        "applicationSourceName",
        "InlineMessage*",
        "distroName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fetchingChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'backendsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatesCountChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'backendDataChanged'
        QtMocHelpers::SignalData<void(AbstractResourcesBackend *, const QVector<QByteArray> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'resourceDataChanged'
        QtMocHelpers::SignalData<void(AbstractResource *, const QVector<QByteArray> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'resourceRemoved'
        QtMocHelpers::SignalData<void(AbstractResource *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'currentApplicationBackendChanged'
        QtMocHelpers::SignalData<void(AbstractResourcesBackend *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 19 },
        }}),
        // Signal 'fetchingUpdatesProgressChanged'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Signal 'inlineMessageChanged'
        QtMocHelpers::SignalData<void(const QSharedPointer<InlineMessage> &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'switchToUpdates'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'installApplication'
        QtMocHelpers::SlotData<void(AbstractResource *, const AddonList &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'installApplication'
        QtMocHelpers::SlotData<void(AbstractResource *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 27 },
        }}),
        // Slot 'removeApplication'
        QtMocHelpers::SlotData<void(AbstractResource *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 27 },
        }}),
        // Slot 'callerContentsChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCaller'
        QtMocHelpers::SlotData<void(const QVector<QByteArray> &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'registerAllBackends'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'isExtended'
        QtMocHelpers::MethodData<bool(const QString &)>(34, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 35 },
        }}),
        // Method 'distroBugReportUrl'
        QtMocHelpers::MethodData<QUrl()>(36, 2, QMC::AccessPublic, 0x80000000 | 37),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'updatesCount'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'hasSecurityUpdates'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'currentApplicationBackend'
        QtMocHelpers::PropertyData<AbstractResourcesBackend*>(19, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'updateAction'
        QtMocHelpers::PropertyData<DiscoverAction*>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fetchingUpdatesProgress'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'remainingDescription'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'applicationSourceName'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'inlineMessage'
        QtMocHelpers::PropertyData<InlineMessage*>(24, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'distroName'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourcesModel, qt_meta_tag_ZN14ResourcesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResourcesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourcesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourcesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ResourcesModelE_t>.metaTypes,
    nullptr
} };

void ResourcesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourcesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fetchingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->backendsChanged(); break;
        case 2: _t->updatesCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->backendDataChanged((*reinterpret_cast<std::add_pointer_t<AbstractResourcesBackend*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 4: _t->resourceDataChanged((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 5: _t->resourceRemoved((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1]))); break;
        case 6: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->currentApplicationBackendChanged((*reinterpret_cast<std::add_pointer_t<AbstractResourcesBackend*>>(_a[1]))); break;
        case 8: _t->fetchingUpdatesProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->inlineMessageChanged((*reinterpret_cast<std::add_pointer_t<QSharedPointer<InlineMessage>>>(_a[1]))); break;
        case 10: _t->switchToUpdates(); break;
        case 11: _t->installApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AddonList>>(_a[2]))); break;
        case 12: _t->installApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1]))); break;
        case 13: _t->removeApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1]))); break;
        case 14: _t->callerContentsChanged(); break;
        case 15: _t->updateCaller((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1]))); break;
        case 16: _t->registerAllBackends(); break;
        case 17: { bool _r = _t->isExtended((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { QUrl _r = _t->distroBugReportUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResourcesBackend* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResourcesBackend* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<InlineMessage> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(bool )>(_a, &ResourcesModel::fetchingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)()>(_a, &ResourcesModel::backendsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(int )>(_a, &ResourcesModel::updatesCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(AbstractResourcesBackend * , const QVector<QByteArray> & )>(_a, &ResourcesModel::backendDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(AbstractResource * , const QVector<QByteArray> & )>(_a, &ResourcesModel::resourceDataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(AbstractResource * )>(_a, &ResourcesModel::resourceRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(const QString & )>(_a, &ResourcesModel::passiveMessage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(AbstractResourcesBackend * )>(_a, &ResourcesModel::currentApplicationBackendChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(int )>(_a, &ResourcesModel::fetchingUpdatesProgressChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)(const QSharedPointer<InlineMessage> & )>(_a, &ResourcesModel::inlineMessageChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesModel::*)()>(_a, &ResourcesModel::switchToUpdates, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractResourcesBackend* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DiscoverAction* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< InlineMessage* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->updatesCount(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasSecurityUpdates(); break;
        case 2: *reinterpret_cast<AbstractResourcesBackend**>(_v) = _t->currentApplicationBackend(); break;
        case 3: *reinterpret_cast<DiscoverAction**>(_v) = _t->updateAction(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->fetchingUpdatesProgress(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->remainingDescription(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->applicationSourceName(); break;
        case 7: *reinterpret_cast<InlineMessage**>(_v) = _t->inlineMessage(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->distroName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCurrentApplicationBackend(*reinterpret_cast<AbstractResourcesBackend**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ResourcesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourcesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourcesModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ResourcesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ResourcesModel::fetchingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ResourcesModel::backendsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ResourcesModel::updatesCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ResourcesModel::backendDataChanged(AbstractResourcesBackend * _t1, const QVector<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ResourcesModel::resourceDataChanged(AbstractResource * _t1, const QVector<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ResourcesModel::resourceRemoved(AbstractResource * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ResourcesModel::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ResourcesModel::currentApplicationBackendChanged(AbstractResourcesBackend * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ResourcesModel::fetchingUpdatesProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ResourcesModel::inlineMessageChanged(const QSharedPointer<InlineMessage> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ResourcesModel::switchToUpdates()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
