// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef DISCOVERDATA_H
#define DISCOVERDATA_H

#include <QObject>

#include "kcmoduledata.h"



class DiscoverSettings;


class DiscoverData : public KCModuleData
{
    Q_OBJECT

public:
    explicit DiscoverData(QObject *parent = nullptr);
    DiscoverSettings *settings() const;


private:
    DiscoverSettings *m_settings;

};



#endif
