/****************************************************************************
** Meta object code from reading C++ file 'AbstractBackendUpdater.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/AbstractBackendUpdater.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractBackendUpdater.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AbstractBackendUpdaterE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractBackendUpdater::qt_create_metaobjectdata<qt_meta_tag_ZN22AbstractBackendUpdaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractBackendUpdater",
        "progressChanged",
        "",
        "progress",
        "cancelableChanged",
        "cancelable",
        "progressingChanged",
        "progressing",
        "statusDetailChanged",
        "msg",
        "statusMessageChanged",
        "downloadSpeedChanged",
        "downloadSpeed",
        "resourceProgressed",
        "AbstractResource*",
        "resource",
        "AbstractBackendUpdater::State",
        "state",
        "passiveMessage",
        "message",
        "proceedRequest",
        "title",
        "description",
        "distroErrorMessage",
        "needsRebootChanged",
        "errorMessageChanged",
        "fetchingChanged",
        "cancel",
        "start",
        "proceed",
        "isCancelable",
        "isProgressing",
        "needsReboot",
        "errorMessage",
        "isFetchingUpdates",
        "State",
        "None",
        "Downloading",
        "Installing",
        "Done"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(qreal)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 3 },
        }}),
        // Signal 'cancelableChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'progressingChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'statusDetailChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'statusMessageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'downloadSpeedChanged'
        QtMocHelpers::SignalData<void(quint64)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 12 },
        }}),
        // Signal 'resourceProgressed'
        QtMocHelpers::SignalData<void(AbstractResource *, qreal, AbstractBackendUpdater::State)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QReal, 3 }, { 0x80000000 | 16, 17 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'proceedRequest'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'distroErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'needsRebootChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchingChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proceed'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'progress'
        QtMocHelpers::PropertyData<qreal>(3, QMetaType::QReal, QMC::DefaultPropertyFlags, 0),
        // property 'isCancelable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isProgressing'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'needsReboot'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'downloadSpeed'
        QtMocHelpers::PropertyData<quint64>(12, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 5),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'isFetchingUpdates'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(35, 35, QMC::EnumFlags{}).add({
            {   36, State::None },
            {   37, State::Downloading },
            {   38, State::Installing },
            {   39, State::Done },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractBackendUpdater, qt_meta_tag_ZN22AbstractBackendUpdaterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractBackendUpdater::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractBackendUpdaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractBackendUpdaterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AbstractBackendUpdaterE_t>.metaTypes,
    nullptr
} };

void AbstractBackendUpdater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractBackendUpdater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 1: _t->cancelableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->progressingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->statusDetailChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->statusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->downloadSpeedChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 6: _t->resourceProgressed((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AbstractBackendUpdater::State>>(_a[3]))); break;
        case 7: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->proceedRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->distroErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->needsRebootChanged(); break;
        case 11: _t->errorMessageChanged(); break;
        case 12: _t->fetchingChanged(); break;
        case 13: _t->cancel(); break;
        case 14: _t->start(); break;
        case 15: _t->proceed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(qreal )>(_a, &AbstractBackendUpdater::progressChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(bool )>(_a, &AbstractBackendUpdater::cancelableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(bool )>(_a, &AbstractBackendUpdater::progressingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(const QString & )>(_a, &AbstractBackendUpdater::statusDetailChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(const QString & )>(_a, &AbstractBackendUpdater::statusMessageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(quint64 )>(_a, &AbstractBackendUpdater::downloadSpeedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(AbstractResource * , qreal , AbstractBackendUpdater::State )>(_a, &AbstractBackendUpdater::resourceProgressed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(const QString & )>(_a, &AbstractBackendUpdater::passiveMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(const QString & , const QString & )>(_a, &AbstractBackendUpdater::proceedRequest, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)(const QString & )>(_a, &AbstractBackendUpdater::distroErrorMessage, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)()>(_a, &AbstractBackendUpdater::needsRebootChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)()>(_a, &AbstractBackendUpdater::errorMessageChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBackendUpdater::*)()>(_a, &AbstractBackendUpdater::fetchingChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->progress(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isCancelable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isProgressing(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->needsReboot(); break;
        case 4: *reinterpret_cast<quint64*>(_v) = _t->downloadSpeed(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isFetchingUpdates(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractBackendUpdater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractBackendUpdater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractBackendUpdaterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractBackendUpdater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void AbstractBackendUpdater::progressChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractBackendUpdater::cancelableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractBackendUpdater::progressingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractBackendUpdater::statusDetailChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AbstractBackendUpdater::statusMessageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractBackendUpdater::downloadSpeedChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AbstractBackendUpdater::resourceProgressed(AbstractResource * _t1, qreal _t2, AbstractBackendUpdater::State _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void AbstractBackendUpdater::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AbstractBackendUpdater::proceedRequest(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void AbstractBackendUpdater::distroErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AbstractBackendUpdater::needsRebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AbstractBackendUpdater::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AbstractBackendUpdater::fetchingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
