/*
 *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 *
 *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */

#include "BackendNotifierModule.h"

BackendNotifierModule::BackendNotifierModule(QObject *parent)
    : QObject(parent)
{
}

BackendNotifierModule::~BackendNotifierModule() = default;

#include "moc_BackendNotifierModule.cpp"
