// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "discoverdata.h"

#include "discoversettings.h"




DiscoverData::DiscoverData(QObject *parent)
: KCModuleData(parent)
, m_settings(new DiscoverSettings(this))

{
autoRegisterSkeletons();
}

DiscoverSettings *DiscoverData::settings() const
{
    return m_settings;
}





#include "moc_discoverdata.cpp"
