/****************************************************************************
** Meta object code from reading C++ file 'AbstractResource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/AbstractResource.h"
#include "resources/AbstractResourcesBackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractResource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AbstractResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractResource::qt_create_metaobjectdata<qt_meta_tag_ZN16AbstractResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractResource",
        "iconChanged",
        "",
        "sizeChanged",
        "stateChanged",
        "licensesChanged",
        "ratingFetched",
        "longDescriptionChanged",
        "versionsChanged",
        "screenshotsFetched",
        "Screenshots",
        "screenshots",
        "changelogFetched",
        "changelog",
        "fetchScreenshots",
        "fetchChangelog",
        "fetchUpdateDetails",
        "invokeApplication",
        "name",
        "packageName",
        "comment",
        "icon",
        "QVariant",
        "canExecute",
        "state",
        "State",
        "status",
        "homepage",
        "QUrl",
        "helpURL",
        "bugURL",
        "donationURL",
        "contributeURL",
        "canUpgrade",
        "isInstalled",
        "licenses",
        "QJsonArray",
        "longDescription",
        "origin",
        "displayOrigin",
        "size",
        "sizeDescription",
        "installedVersion",
        "availableVersion",
        "section",
        "mimetypes",
        "backend",
        "AbstractResourcesBackend*",
        "rating",
        "Rating",
        "appstreamId",
        "url",
        "executeLabel",
        "sourceIcon",
        "author",
        "releaseDate",
        "upgradeText",
        "isRemovable",
        "versionString",
        "contentRatingDescription",
        "contentRatingMinimumAge",
        "topObjects",
        "bottomObjects",
        "verifiedMessage",
        "verifiedIconName",
        "type",
        "Type",
        "Broken",
        "None",
        "Installed",
        "Upgradeable",
        "Application",
        "Addon",
        "ApplicationSupport",
        "System"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licensesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ratingFetched'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'longDescriptionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'versionsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenshotsFetched'
        QtMocHelpers::SignalData<void(const Screenshots &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'changelogFetched'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'fetchScreenshots'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fetchChangelog'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fetchUpdateDetails'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'invokeApplication'
        QtMocHelpers::MethodData<void() const>(17, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'packageName'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'icon'
        QtMocHelpers::PropertyData<QVariant>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'canExecute'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'status'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'homepage'
        QtMocHelpers::PropertyData<QUrl>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'helpURL'
        QtMocHelpers::PropertyData<QUrl>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'bugURL'
        QtMocHelpers::PropertyData<QUrl>(30, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'donationURL'
        QtMocHelpers::PropertyData<QUrl>(31, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'contributeURL'
        QtMocHelpers::PropertyData<QUrl>(32, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'canUpgrade'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'isInstalled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'licenses'
        QtMocHelpers::PropertyData<QJsonArray>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'longDescription'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'origin'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayOrigin'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'size'
        QtMocHelpers::PropertyData<quint64>(40, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 1),
        // property 'sizeDescription'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'installedVersion'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'availableVersion'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'section'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mimetypes'
        QtMocHelpers::PropertyData<QStringList>(45, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'backend'
        QtMocHelpers::PropertyData<AbstractResourcesBackend*>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'rating'
        QtMocHelpers::PropertyData<Rating>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'appstreamId'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(51, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'executeLabel'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sourceIcon'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'releaseDate'
        QtMocHelpers::PropertyData<QDate>(55, QMetaType::QDate, QMC::DefaultPropertyFlags, 6),
        // property 'upgradeText'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'isRemovable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'versionString'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'contentRatingDescription'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'contentRatingMinimumAge'
        QtMocHelpers::PropertyData<uint>(60, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'topObjects'
        QtMocHelpers::PropertyData<QStringList>(61, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bottomObjects'
        QtMocHelpers::PropertyData<QStringList>(62, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'verifiedMessage'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'verifiedIconName'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(25, 25, QMC::EnumFlags{}).add({
            {   67, State::Broken },
            {   68, State::None },
            {   69, State::Installed },
            {   70, State::Upgradeable },
        }),
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(66, 66, QMC::EnumFlags{}).add({
            {   71, Type::Application },
            {   72, Type::Addon },
            {   73, Type::ApplicationSupport },
            {   74, Type::System },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractResource, qt_meta_tag_ZN16AbstractResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractResource::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AbstractResourceE_t>.metaTypes,
    nullptr
} };

void AbstractResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->iconChanged(); break;
        case 1: _t->sizeChanged(); break;
        case 2: _t->stateChanged(); break;
        case 3: _t->licensesChanged(); break;
        case 4: _t->ratingFetched(); break;
        case 5: _t->longDescriptionChanged(); break;
        case 6: _t->versionsChanged(); break;
        case 7: _t->screenshotsFetched((*reinterpret_cast<std::add_pointer_t<Screenshots>>(_a[1]))); break;
        case 8: _t->changelogFetched((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->fetchScreenshots(); break;
        case 10: _t->fetchChangelog(); break;
        case 11: _t->fetchUpdateDetails(); break;
        case 12: _t->invokeApplication(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::iconChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::sizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::stateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::licensesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::ratingFetched, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::longDescriptionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)()>(_a, &AbstractResource::versionsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)(const Screenshots & )>(_a, &AbstractResource::screenshotsFetched, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResource::*)(const QString & )>(_a, &AbstractResource::changelogFetched, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->packageName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->comment(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->icon(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canExecute(); break;
        case 5: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->homepage(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->helpURL(); break;
        case 9: *reinterpret_cast<QUrl*>(_v) = _t->bugURL(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->donationURL(); break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->contributeURL(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->canUpgrade(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isInstalled(); break;
        case 14: *reinterpret_cast<QJsonArray*>(_v) = _t->licenses(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->longDescription(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->origin(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->displayOrigin(); break;
        case 18: *reinterpret_cast<quint64*>(_v) = _t->size(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->sizeDescription(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->installedVersion(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->availableVersion(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->section(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->mimetypes(); break;
        case 24: *reinterpret_cast<AbstractResourcesBackend**>(_v) = _t->backend(); break;
        case 25: *reinterpret_cast<Rating*>(_v) = _t->rating(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->appstreamId(); break;
        case 27: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->executeLabel(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->sourceIcon(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 31: *reinterpret_cast<QDate*>(_v) = _t->releaseDate(); break;
        case 32: *reinterpret_cast<QString*>(_v) = _t->upgradeText(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isRemovable(); break;
        case 34: *reinterpret_cast<QString*>(_v) = _t->versionString(); break;
        case 35: *reinterpret_cast<QString*>(_v) = _t->contentRatingDescription(); break;
        case 36: *reinterpret_cast<uint*>(_v) = _t->contentRatingMinimumAge(); break;
        case 37: *reinterpret_cast<QStringList*>(_v) = _t->topObjects(); break;
        case 38: *reinterpret_cast<QStringList*>(_v) = _t->bottomObjects(); break;
        case 39: *reinterpret_cast<QString*>(_v) = _t->verifiedMessage(); break;
        case 40: *reinterpret_cast<QString*>(_v) = _t->verifiedIconName(); break;
        case 41: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractResourceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void AbstractResource::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractResource::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractResource::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractResource::licensesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractResource::ratingFetched()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractResource::longDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AbstractResource::versionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AbstractResource::screenshotsFetched(const Screenshots & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AbstractResource::changelogFetched(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
