// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "libdiscover_backend_packagekit_debug.h"


Q_LOGGING_CATEGORY(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG, "org.kde.plasma.libdiscover.backend.packagekit", QtInfoMsg)

