/****************************************************************************
** Meta object code from reading C++ file 'PackageKitDependencies.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/PackageKitBackend/PackageKitDependencies.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PackageKitDependencies.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20PackageKitDependencyE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitDependency::qt_create_metaobjectdata<qt_meta_tag_ZN20PackageKitDependencyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitDependency",
        "info",
        "PackageKit::Transaction::Info",
        "infoString",
        "packageId",
        "packageName",
        "summary"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'info'
        QtMocHelpers::PropertyData<PackageKit::Transaction::Info>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'infoString'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'packageId'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'packageName'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitDependency, qt_meta_tag_ZN20PackageKitDependencyE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN20PackageKitDependencyE[] = {
    QMetaObject::SuperData::link<PackageKit::Transaction::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PackageKitDependency::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PackageKitDependencyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PackageKitDependencyE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN20PackageKitDependencyE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20PackageKitDependencyE_t>.metaTypes,
    nullptr
} };

void PackageKitDependency::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PackageKitDependency *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PackageKit::Transaction::Info >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PackageKit::Transaction::Info*>(_v) = _t->m_info; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_infoString; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_packageId; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->packageName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_summary; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN22PackageKitDependenciesE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitDependencies::qt_create_metaobjectdata<qt_meta_tag_ZN22PackageKitDependenciesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitDependencies",
        "packageIdChanged",
        "",
        "dependenciesChanged",
        "onJobFinished",
        "QList<PackageKitDependency>",
        "dependencies",
        "packageId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'packageIdChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dependenciesChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onJobFinished'
        QtMocHelpers::SlotData<void(const QList<PackageKitDependency> &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'packageId'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'dependencies'
        QtMocHelpers::PropertyData<QList<PackageKitDependency>>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitDependencies, qt_meta_tag_ZN22PackageKitDependenciesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PackageKitDependencies::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PackageKitDependenciesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PackageKitDependenciesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22PackageKitDependenciesE_t>.metaTypes,
    nullptr
} };

void PackageKitDependencies::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackageKitDependencies *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->packageIdChanged(); break;
        case 1: _t->dependenciesChanged(); break;
        case 2: _t->onJobFinished((*reinterpret_cast<std::add_pointer_t<QList<PackageKitDependency>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PackageKitDependencies::*)()>(_a, &PackageKitDependencies::packageIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PackageKitDependencies::*)()>(_a, &PackageKitDependencies::dependenciesChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->packageId(); break;
        case 1: *reinterpret_cast<QList<PackageKitDependency>*>(_v) = _t->dependencies(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPackageId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PackageKitDependencies::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PackageKitDependencies::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PackageKitDependenciesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PackageKitDependencies::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void PackageKitDependencies::packageIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PackageKitDependencies::dependenciesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitFetchDependenciesJob::qt_create_metaobjectdata<qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitFetchDependenciesJob",
        "finished",
        "",
        "QList<PackageKitDependency>",
        "dependencies",
        "onTransactionErrorCode",
        "PackageKit::Transaction::Error",
        "error",
        "details",
        "onTransactionPackage",
        "PackageKit::Transaction::Info",
        "info",
        "packageId",
        "summary",
        "onTransactionFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(QList<PackageKitDependency>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onTransactionErrorCode'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Error, const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'onTransactionPackage'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Info, const QString &, const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'onTransactionFinished'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitFetchDependenciesJob, qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PackageKitFetchDependenciesJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>.metaTypes,
    nullptr
} };

void PackageKitFetchDependenciesJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackageKitFetchDependenciesJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QList<PackageKitDependency>>>(_a[1]))); break;
        case 1: _t->onTransactionErrorCode((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Error>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->onTransactionPackage((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Info>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->onTransactionFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Error >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Info >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PackageKitFetchDependenciesJob::*)(QList<PackageKitDependency> )>(_a, &PackageKitFetchDependenciesJob::finished, 0))
            return;
    }
}

const QMetaObject *PackageKitFetchDependenciesJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PackageKitFetchDependenciesJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30PackageKitFetchDependenciesJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PackageKitFetchDependenciesJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PackageKitFetchDependenciesJob::finished(QList<PackageKitDependency> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
