/****************************************************************************
** Meta object code from reading C++ file 'PackageKitNotifier.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/PackageKitBackend/PackageKitNotifier.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PackageKitNotifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PackageKitNotifierE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitNotifier::qt_create_metaobjectdata<qt_meta_tag_ZN18PackageKitNotifierE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitNotifier",
        "package",
        "",
        "PackageKit::Transaction::Info",
        "info",
        "packageID",
        "summary",
        "finished",
        "PackageKit::Transaction::Exit",
        "exit",
        "onRequireRestart",
        "PackageKit::Transaction::Restart",
        "type",
        "transactionListChanged",
        "transactionIDs",
        "checkNeedsReboot"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'package'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Info, const QString &, const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'finished'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Exit, uint)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::UInt, 2 },
        }}),
        // Slot 'onRequireRestart'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Restart, const QString &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'transactionListChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Slot 'checkNeedsReboot'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitNotifier, qt_meta_tag_ZN18PackageKitNotifierE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PackageKitNotifier::staticMetaObject = { {
    QMetaObject::SuperData::link<BackendNotifierModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitNotifierE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitNotifierE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PackageKitNotifierE_t>.metaTypes,
    nullptr
} };

void PackageKitNotifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackageKitNotifier *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->package((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Info>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->finished((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Exit>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->onRequireRestart((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Restart>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->transactionListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->checkNeedsReboot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Info >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Exit >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Restart >(); break;
            }
            break;
        }
    }
}

const QMetaObject *PackageKitNotifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PackageKitNotifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitNotifierE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.discover.6.7.3.BackendNotifierModule"))
        return static_cast< BackendNotifierModule*>(this);
    return BackendNotifierModule::qt_metacast(_clname);
}

int PackageKitNotifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BackendNotifierModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_PackageKitNotifier[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2c,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'd',  'i',  's',  'c',  'o', 
    'v',  'e',  'r',  '.',  '6',  '.',  '7',  '.', 
    '3',  '.',  'B',  'a',  'c',  'k',  'e',  'n', 
    'd',  'N',  'o',  't',  'i',  'f',  'i',  'e', 
    'r',  'M',  'o',  'd',  'u',  'l',  'e', 
    // "className"
    0x03,  0x72,  'P',  'a',  'c',  'k',  'a',  'g', 
    'e',  'K',  'i',  't',  'N',  'o',  't',  'i', 
    'f',  'i',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(PackageKitNotifier, PackageKitNotifier, qt_pluginMetaDataV2_PackageKitNotifier)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_PackageKitNotifier[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2c,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'd',  'i',  's',  'c',  'o', 
    'v',  'e',  'r',  '.',  '6',  '.',  '7',  '.', 
    '3',  '.',  'B',  'a',  'c',  'k',  'e',  'n', 
    'd',  'N',  'o',  't',  'i',  'f',  'i',  'e', 
    'r',  'M',  'o',  'd',  'u',  'l',  'e', 
    // "className"
    0x03,  0x72,  'P',  'a',  'c',  'k',  'a',  'g', 
    'e',  'K',  'i',  't',  'N',  'o',  't',  'i', 
    'f',  'i',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(PackageKitNotifier, PackageKitNotifier)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
