/****************************************************************************
** Meta object code from reading C++ file 'DiscoverObject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/discover/DiscoverObject.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DiscoverObject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DiscoverObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto DiscoverObject::qt_create_metaobjectdata<qt_meta_tag_ZN14DiscoverObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiscoverObject",
        "openSearch",
        "",
        "search",
        "openApplicationInternal",
        "AbstractResource*",
        "app",
        "listMimeInternal",
        "mime",
        "listCategoryInternal",
        "std::shared_ptr<Category>",
        "cat",
        "unableToFind",
        "resid",
        "openErrorPage",
        "errorMessage",
        "errorExplanation",
        "buttonText",
        "buttonIcon",
        "buttonURL",
        "homeMessageChanged",
        "sidebarWidthChanged",
        "width",
        "openApplication",
        "QUrl",
        "openMimeType",
        "openCategory",
        "category",
        "openMode",
        "mode",
        "openLocalPackage",
        "localfile",
        "startHeadlessUpdate",
        "promptReboot",
        "rebootNow",
        "shutdownNow",
        "reconsiderQuit",
        "switchApplicationLanguage",
        "iconName",
        "QIcon",
        "icon",
        "copyTextToClipboard",
        "text",
        "searchUrl",
        "searchText",
        "mimeTypeComment",
        "mimeTypeName",
        "restore",
        "quitWhenIdle",
        "isRoot",
        "mainWindow",
        "QQuickWindow*",
        "homePageMessage",
        "InlineMessage*",
        "sidebarWidth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openSearch'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'openApplicationInternal'
        QtMocHelpers::SignalData<void(AbstractResource *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'listMimeInternal'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'listCategoryInternal'
        QtMocHelpers::SignalData<void(const std::shared_ptr<Category> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'unableToFind'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'openErrorPage'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 },
        }}),
        // Signal 'homeMessageChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidebarWidthChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'openApplication'
        QtMocHelpers::SlotData<void(const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 6 },
        }}),
        // Slot 'openMimeType'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'openCategory'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'openMode'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'openLocalPackage'
        QtMocHelpers::SlotData<void(const QUrl &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 31 },
        }}),
        // Slot 'startHeadlessUpdate'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'promptReboot'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rebootNow'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shutdownNow'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconsiderQuit'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchApplicationLanguage'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'iconName'
        QtMocHelpers::MethodData<QString(const QIcon &)>(38, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Method 'copyTextToClipboard'
        QtMocHelpers::MethodData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Method 'searchUrl'
        QtMocHelpers::MethodData<QUrl(const QString &)>(43, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 44 },
        }}),
        // Method 'mimeTypeComment'
        QtMocHelpers::MethodData<QString(const QString &)>(45, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 46 },
        }}),
        // Method 'restore'
        QtMocHelpers::MethodData<void()>(47, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'quitWhenIdle'
        QtMocHelpers::MethodData<bool()>(48, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isRoot'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mainWindow'
        QtMocHelpers::PropertyData<QQuickWindow*>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'homePageMessage'
        QtMocHelpers::PropertyData<InlineMessage*>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'sidebarWidth'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DiscoverObject, qt_meta_tag_ZN14DiscoverObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DiscoverObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiscoverObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiscoverObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DiscoverObjectE_t>.metaTypes,
    nullptr
} };

void DiscoverObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiscoverObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openApplicationInternal((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1]))); break;
        case 2: _t->listMimeInternal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->listCategoryInternal((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Category>>>(_a[1]))); break;
        case 4: _t->unableToFind((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->openErrorPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 6: _t->homeMessageChanged(); break;
        case 7: _t->sidebarWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->openApplication((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->openMimeType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->openCategory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->openMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->openLocalPackage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->startHeadlessUpdate(); break;
        case 14: _t->promptReboot(); break;
        case 15: _t->rebootNow(); break;
        case 16: _t->shutdownNow(); break;
        case 17: _t->reconsiderQuit(); break;
        case 18: _t->switchApplicationLanguage(); break;
        case 19: { QString _r = _t->iconName((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->copyTextToClipboard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { QUrl _r = _t->searchUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->mimeTypeComment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->restore(); break;
        case 24: { bool _r = _t->quitWhenIdle();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< std::shared_ptr<Category> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(const QString & )>(_a, &DiscoverObject::openSearch, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(AbstractResource * )>(_a, &DiscoverObject::openApplicationInternal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(const QString & )>(_a, &DiscoverObject::listMimeInternal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(const std::shared_ptr<Category> & )>(_a, &DiscoverObject::listCategoryInternal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(const QString & )>(_a, &DiscoverObject::unableToFind, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(const QString & , const QString & , const QString & , const QString & , const QString & )>(_a, &DiscoverObject::openErrorPage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)()>(_a, &DiscoverObject::homeMessageChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiscoverObject::*)(int )>(_a, &DiscoverObject::sidebarWidthChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isRoot(); break;
        case 1: *reinterpret_cast<QQuickWindow**>(_v) = _t->mainWindow(); break;
        case 2: *reinterpret_cast<InlineMessage**>(_v) = _t->homePageMessage(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->sidebarWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setSidebarWidth(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DiscoverObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiscoverObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DiscoverObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DiscoverObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DiscoverObject::openSearch(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DiscoverObject::openApplicationInternal(AbstractResource * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DiscoverObject::listMimeInternal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DiscoverObject::listCategoryInternal(const std::shared_ptr<Category> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DiscoverObject::unableToFind(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DiscoverObject::openErrorPage(const QString & _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 6
void DiscoverObject::homeMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DiscoverObject::sidebarWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
