// This file is generated by kconfig_compiler_kf6 from discoversettings.kcfg.
// All changes you do to this file will be lost.
#ifndef DISCOVERSETTINGS_H
#define DISCOVERSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class DiscoverSettings : public KConfigSkeleton
{
  Q_OBJECT
  public:

    DiscoverSettings( QObject *parent = nullptr );
    ~DiscoverSettings() override;

    /**
      Set UseOfflineUpdates
    */
    void setUseOfflineUpdates( bool v )
    {
      if (v != mUseOfflineUpdates && !isUseOfflineUpdatesImmutable()) {
        mUseOfflineUpdates = v;
        Q_EMIT UseOfflineUpdatesChanged();
      }
    }

    Q_PROPERTY(bool useOfflineUpdates READ useOfflineUpdates WRITE setUseOfflineUpdates NOTIFY UseOfflineUpdatesChanged)
    Q_PROPERTY(bool isUseOfflineUpdatesImmutable READ isUseOfflineUpdatesImmutable CONSTANT)
    Q_PROPERTY(bool defaultUseOfflineUpdatesValue READ defaultUseOfflineUpdatesValue CONSTANT)
    /**
      Get UseOfflineUpdates
    */
    bool useOfflineUpdates() const
    {
      return mUseOfflineUpdates;
    }

    /**
      Is UseOfflineUpdates Immutable
    */
    bool isUseOfflineUpdatesImmutable() const
    {
      return isImmutable( QStringLiteral( "UseOfflineUpdates" ) );
    }

    /**
      Get UseOfflineUpdates default value
    */
    bool defaultUseOfflineUpdatesValue() const
    {
        return defaultUseOfflineUpdatesValue_helper();
    }


    enum {
      signalUseOfflineUpdatesChanged = 1
    };

  Q_SIGNALS:
    void UseOfflineUpdatesChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:

    // Software
    bool mUseOfflineUpdates;
    bool defaultUseOfflineUpdatesValue_helper() const;
};

#endif

