/****************************************************************************
** Meta object code from reading C++ file 'AbstractSourcesBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/AbstractSourcesBackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractSourcesBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AbstractSourcesBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractSourcesBackend::qt_create_metaobjectdata<qt_meta_tag_ZN22AbstractSourcesBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractSourcesBackend",
        "firstDisambiguatedSourceIdChanged",
        "",
        "lastDisambiguatedSourceIdChanged",
        "passiveMessage",
        "message",
        "proceedRequest",
        "title",
        "description",
        "cancel",
        "proceed",
        "addSource",
        "id",
        "removeSource",
        "moveSource",
        "sourceId",
        "delta",
        "resourcesBackend",
        "AbstractResourcesBackend*",
        "sources",
        "QAbstractItemModel*",
        "idDescription",
        "actions",
        "QVariantList",
        "inlineAction",
        "DiscoverAction*",
        "supportsAdding",
        "canMoveSources",
        "canFilterSources",
        "firstDisambiguatedSourceId",
        "lastDisambiguatedSourceId",
        "Roles",
        "IdRole",
        "DisambiguatedIdRole",
        "LastRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'firstDisambiguatedSourceIdChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastDisambiguatedSourceIdChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'proceedRequest'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proceed'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'addSource'
        QtMocHelpers::MethodData<bool(const QString &)>(11, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'removeSource'
        QtMocHelpers::MethodData<bool(const QString &)>(13, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'moveSource'
        QtMocHelpers::MethodData<bool(const QString &, int)>(14, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resourcesBackend'
        QtMocHelpers::PropertyData<AbstractResourcesBackend*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sources'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'idDescription'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'actions'
        QtMocHelpers::PropertyData<QVariantList>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'inlineAction'
        QtMocHelpers::PropertyData<DiscoverAction*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'supportsAdding'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canMoveSources'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canFilterSources'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'firstDisambiguatedSourceId'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'lastDisambiguatedSourceId'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(31, 31, QMC::EnumFlags{}).add({
            {   32, Roles::IdRole },
            {   33, Roles::DisambiguatedIdRole },
            {   34, Roles::LastRole },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractSourcesBackend, qt_meta_tag_ZN22AbstractSourcesBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractSourcesBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractSourcesBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractSourcesBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AbstractSourcesBackendE_t>.metaTypes,
    nullptr
} };

void AbstractSourcesBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractSourcesBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->firstDisambiguatedSourceIdChanged(); break;
        case 1: _t->lastDisambiguatedSourceIdChanged(); break;
        case 2: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->proceedRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->cancel(); break;
        case 5: _t->proceed(); break;
        case 6: { bool _r = _t->addSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->removeSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->moveSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractSourcesBackend::*)()>(_a, &AbstractSourcesBackend::firstDisambiguatedSourceIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractSourcesBackend::*)()>(_a, &AbstractSourcesBackend::lastDisambiguatedSourceIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractSourcesBackend::*)(const QString & )>(_a, &AbstractSourcesBackend::passiveMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractSourcesBackend::*)(const QString & , const QString & )>(_a, &AbstractSourcesBackend::proceedRequest, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DiscoverAction* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AbstractResourcesBackend**>(_v) = _t->resourcesBackend(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sources(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->idDescription(); break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->actions(); break;
        case 4: *reinterpret_cast<DiscoverAction**>(_v) = _t->inlineAction(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->supportsAdding(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canMoveSources(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->canFilterSources(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->firstDisambiguatedSourceId(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->lastDisambiguatedSourceId(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractSourcesBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractSourcesBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractSourcesBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractSourcesBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AbstractSourcesBackend::firstDisambiguatedSourceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractSourcesBackend::lastDisambiguatedSourceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractSourcesBackend::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractSourcesBackend::proceedRequest(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
