// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef UPDATESDATA_H
#define UPDATESDATA_H

#include <QObject>

#include "kcmoduledata.h"



class UpdatesSettings;


class UpdatesData : public KCModuleData
{
    Q_OBJECT

public:
    explicit UpdatesData(QObject *parent = nullptr);
    UpdatesSettings *settings() const;


private:
    UpdatesSettings *m_settings;

};



#endif
