// This file is generated by kconfig_compiler_kf6 from discoversettings.kcfg.
// All changes you do to this file will be lost.

#include "discoversettings.h"

DiscoverSettings::DiscoverSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "discoverrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&DiscoverSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Software" ) );

  KConfigCompilerSignallingItem  *itemUseOfflineUpdates;
  KConfigSkeleton::ItemBool  *innerItemUseOfflineUpdates;
  innerItemUseOfflineUpdates = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseOfflineUpdates" ), mUseOfflineUpdates, false );
  itemUseOfflineUpdates = new KConfigCompilerSignallingItem(innerItemUseOfflineUpdates, this, notifyFunction, signalUseOfflineUpdatesChanged);
  itemUseOfflineUpdates->setWriteFlags(KConfigBase::Notify);
  addItem( itemUseOfflineUpdates, QStringLiteral( "UseOfflineUpdates" ) );
}

bool DiscoverSettings::defaultUseOfflineUpdatesValue_helper() const
{

  return false;
}

DiscoverSettings::~DiscoverSettings()
{
}


void DiscoverSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalUseOfflineUpdatesChanged:
    Q_EMIT UseOfflineUpdatesChanged();
    break;
  }
}
