// This file is generated by kconfig_compiler_kf6 from plasmauserfeedback.kcfg.
// All changes you do to this file will be lost.

#include "plasmauserfeedback.h"

PlasmaUserFeedback::PlasmaUserFeedback( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&PlasmaUserFeedback::itemChanged);

  setCurrentGroup( QStringLiteral( "Global" ) );

  KConfigCompilerSignallingItem  *itemFeedbackLevel;
  KConfigSkeleton::ItemInt  *innerItemFeedbackLevel;
  innerItemFeedbackLevel = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "FeedbackLevel" ), mFeedbackLevel, int(KUserFeedback::Provider::NoTelemetry) );
  itemFeedbackLevel = new KConfigCompilerSignallingItem(innerItemFeedbackLevel, this, notifyFunction, signalFeedbackLevelChanged);
  addItem( itemFeedbackLevel, QStringLiteral( "FeedbackLevel" ) );
}

PlasmaUserFeedback::~PlasmaUserFeedback()
{
}


void PlasmaUserFeedback::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalFeedbackLevelChanged:
    Q_EMIT FeedbackLevelChanged();
    break;
  }
}
