/****************************************************************************
** Meta object code from reading C++ file 'AbstractReviewsBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/ReviewsBackend/AbstractReviewsBackend.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractReviewsBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ReviewsJobE_t {};
} // unnamed namespace

template <> constexpr inline auto ReviewsJob::qt_create_metaobjectdata<qt_meta_tag_ZN10ReviewsJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReviewsJob",
        "reviewsReady",
        "",
        "QList<ReviewPtr>",
        "reviews",
        "canFetchMore",
        "errorMessage",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reviewsReady'
        QtMocHelpers::SignalData<void(const QVector<ReviewPtr> &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReviewsJob, qt_meta_tag_ZN10ReviewsJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReviewsJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReviewsJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReviewsJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ReviewsJobE_t>.metaTypes,
    nullptr
} };

void ReviewsJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReviewsJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reviewsReady((*reinterpret_cast<std::add_pointer_t<QList<ReviewPtr>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReviewsJob::*)(const QVector<ReviewPtr> & , bool )>(_a, &ReviewsJob::reviewsReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReviewsJob::*)(const QString & )>(_a, &ReviewsJob::errorMessage, 1))
            return;
    }
}

const QMetaObject *ReviewsJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReviewsJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReviewsJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ReviewsJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ReviewsJob::reviewsReady(const QVector<ReviewPtr> & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ReviewsJob::errorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN22AbstractReviewsBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractReviewsBackend::qt_create_metaobjectdata<qt_meta_tag_ZN22AbstractReviewsBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractReviewsBackend",
        "error",
        "",
        "message",
        "fetchingChanged",
        "fetching",
        "preferredUserNameChanged",
        "errorMessageChanged",
        "login",
        "registerAndLogin",
        "logout",
        "submitUsefulness",
        "Review*",
        "review",
        "useful",
        "submitReview",
        "ReviewsJob*",
        "AbstractResource*",
        "resource",
        "summary",
        "reviewText",
        "rating",
        "userName",
        "deleteReview",
        "flagReview",
        "reason",
        "text",
        "fetchReviews",
        "page",
        "ratingForApplication",
        "Rating",
        "errorMessage",
        "isResourceSupported",
        "isReviewable",
        "supportsNameChange",
        "preferredUserName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'fetchingChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'preferredUserNameChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'login'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'registerAndLogin'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'logout'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submitUsefulness'
        QtMocHelpers::SlotData<void(Review *, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'submitReview'
        QtMocHelpers::SlotData<ReviewsJob *(AbstractResource *, const QString &, const QString &, const QString &, const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { QMetaType::QString, 22 },
        }}),
        // Slot 'deleteReview'
        QtMocHelpers::SlotData<void(Review *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'flagReview'
        QtMocHelpers::SlotData<void(Review *, const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'fetchReviews'
        QtMocHelpers::SlotData<ReviewsJob *(AbstractResource *, int)>(27, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'fetchReviews'
        QtMocHelpers::SlotData<ReviewsJob *(AbstractResource *)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'ratingForApplication'
        QtMocHelpers::MethodData<Rating(AbstractResource *) const>(29, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 30, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'errorMessage'
        QtMocHelpers::MethodData<QString() const>(31, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'isResourceSupported'
        QtMocHelpers::MethodData<bool(AbstractResource *) const>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isReviewable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportsNameChange'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preferredUserName'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractReviewsBackend, qt_meta_tag_ZN22AbstractReviewsBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractReviewsBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractReviewsBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractReviewsBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AbstractReviewsBackendE_t>.metaTypes,
    nullptr
} };

void AbstractReviewsBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractReviewsBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->fetchingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->preferredUserNameChanged(); break;
        case 3: _t->errorMessageChanged(); break;
        case 4: _t->login(); break;
        case 5: _t->registerAndLogin(); break;
        case 6: _t->logout(); break;
        case 7: _t->submitUsefulness((*reinterpret_cast<std::add_pointer_t<Review*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: { ReviewsJob* _r = _t->submitReview((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<ReviewsJob**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->deleteReview((*reinterpret_cast<std::add_pointer_t<Review*>>(_a[1]))); break;
        case 10: _t->flagReview((*reinterpret_cast<std::add_pointer_t<Review*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: { ReviewsJob* _r = _t->fetchReviews((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<ReviewsJob**>(_a[0]) = std::move(_r); }  break;
        case 12: { ReviewsJob* _r = _t->fetchReviews((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ReviewsJob**>(_a[0]) = std::move(_r); }  break;
        case 13: { Rating _r = _t->ratingForApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Rating*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->errorMessage();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isResourceSupported((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractReviewsBackend::*)(const QString & )>(_a, &AbstractReviewsBackend::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractReviewsBackend::*)(bool )>(_a, &AbstractReviewsBackend::fetchingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractReviewsBackend::*)()>(_a, &AbstractReviewsBackend::preferredUserNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractReviewsBackend::*)()>(_a, &AbstractReviewsBackend::errorMessageChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isReviewable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->supportsNameChange(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->preferredUserName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractReviewsBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractReviewsBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractReviewsBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractReviewsBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AbstractReviewsBackend::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractReviewsBackend::fetchingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractReviewsBackend::preferredUserNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractReviewsBackend::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
