/****************************************************************************
** Meta object code from reading C++ file 'ResourcesUpdatesModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/ResourcesUpdatesModel.h"
#include "Transaction/Transaction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ResourcesUpdatesModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ResourcesUpdatesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourcesUpdatesModel::qt_create_metaobjectdata<qt_meta_tag_ZN21ResourcesUpdatesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourcesUpdatesModel",
        "downloadSpeedChanged",
        "",
        "progressingChanged",
        "finished",
        "resourceProgressed",
        "AbstractResource*",
        "resource",
        "progress",
        "AbstractBackendUpdater::State",
        "state",
        "passiveMessage",
        "message",
        "needsRebootChanged",
        "useUnattendedUpdatesChanged",
        "fetchingUpdatesProgressChanged",
        "percent",
        "errorMessagesChanged",
        "fetchingChanged",
        "updateAll",
        "updaterDestroyed",
        "obj",
        "msg",
        "prepare",
        "isProgressing",
        "isFetching",
        "lastUpdate",
        "secsToLastUpdate",
        "transaction",
        "Transaction*",
        "needsReboot",
        "readyToReboot",
        "useUnattendedUpdates",
        "errorMessages"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downloadSpeedChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressingChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resourceProgressed'
        QtMocHelpers::SignalData<void(AbstractResource *, qreal, AbstractBackendUpdater::State)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QReal, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'needsRebootChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useUnattendedUpdatesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchingUpdatesProgressChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'errorMessagesChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchingChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAll'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updaterDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 21 },
        }}),
        // Slot 'message'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'prepare'
        QtMocHelpers::MethodData<void()>(23, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isProgressing'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isFetching'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'lastUpdate'
        QtMocHelpers::PropertyData<QDateTime>(26, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 1),
        // property 'secsToLastUpdate'
        QtMocHelpers::PropertyData<qint64>(27, QMetaType::LongLong, QMC::DefaultPropertyFlags, 1),
        // property 'transaction'
        QtMocHelpers::PropertyData<Transaction*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'needsReboot'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'readyToReboot'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'useUnattendedUpdates'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'errorMessages'
        QtMocHelpers::PropertyData<QStringList>(33, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourcesUpdatesModel, qt_meta_tag_ZN21ResourcesUpdatesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResourcesUpdatesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QStandardItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ResourcesUpdatesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ResourcesUpdatesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ResourcesUpdatesModelE_t>.metaTypes,
    nullptr
} };

void ResourcesUpdatesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourcesUpdatesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downloadSpeedChanged(); break;
        case 1: _t->progressingChanged(); break;
        case 2: _t->finished(); break;
        case 3: _t->resourceProgressed((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AbstractBackendUpdater::State>>(_a[3]))); break;
        case 4: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->needsRebootChanged(); break;
        case 6: _t->useUnattendedUpdatesChanged(); break;
        case 7: _t->fetchingUpdatesProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->errorMessagesChanged(); break;
        case 9: _t->fetchingChanged(); break;
        case 10: _t->updateAll(); break;
        case 11: _t->updaterDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 12: _t->message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->prepare(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::downloadSpeedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::progressingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::finished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)(AbstractResource * , qreal , AbstractBackendUpdater::State )>(_a, &ResourcesUpdatesModel::resourceProgressed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)(const QString & )>(_a, &ResourcesUpdatesModel::passiveMessage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::needsRebootChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::useUnattendedUpdatesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)(int )>(_a, &ResourcesUpdatesModel::fetchingUpdatesProgressChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::errorMessagesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesUpdatesModel::*)()>(_a, &ResourcesUpdatesModel::fetchingChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isProgressing(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFetching(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->lastUpdate(); break;
        case 3: *reinterpret_cast<qint64*>(_v) = _t->secsToLastUpdate(); break;
        case 4: *reinterpret_cast<Transaction**>(_v) = _t->transaction(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->needsReboot(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->readyToReboot(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->useUnattendedUpdates(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->errorMessages(); break;
        default: break;
        }
    }
}

const QMetaObject *ResourcesUpdatesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourcesUpdatesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ResourcesUpdatesModelE_t>.strings))
        return static_cast<void*>(this);
    return QStandardItemModel::qt_metacast(_clname);
}

int ResourcesUpdatesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStandardItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ResourcesUpdatesModel::downloadSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ResourcesUpdatesModel::progressingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ResourcesUpdatesModel::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ResourcesUpdatesModel::resourceProgressed(AbstractResource * _t1, qreal _t2, AbstractBackendUpdater::State _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void ResourcesUpdatesModel::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ResourcesUpdatesModel::needsRebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ResourcesUpdatesModel::useUnattendedUpdatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ResourcesUpdatesModel::fetchingUpdatesProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ResourcesUpdatesModel::errorMessagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ResourcesUpdatesModel::fetchingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
