// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "updatesdata.h"

#include "updatessettings.h"




UpdatesData::UpdatesData(QObject *parent)
: KCModuleData(parent)
, m_settings(new UpdatesSettings(this))

{
autoRegisterSkeletons();
}

UpdatesSettings *UpdatesData::settings() const
{
    return m_settings;
}





#include "moc_updatesdata.cpp"
