/****************************************************************************
** Meta object code from reading C++ file 'PackageKitResource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/PackageKitBackend/PackageKitResource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PackageKitResource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PackageKitResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitResource::qt_create_metaobjectdata<qt_meta_tag_ZN18PackageKitResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitResource",
        "dependenciesChanged",
        "",
        "addPackageId",
        "PackageKit::Transaction::Info",
        "info",
        "packageId",
        "arch",
        "setDetails",
        "PackageKit::Details",
        "details",
        "updateDetail",
        "packageID",
        "updates",
        "obsoletes",
        "vendorUrls",
        "bugzillaUrls",
        "cveUrls",
        "PackageKit::Transaction::Restart",
        "restart",
        "updateText",
        "changelog",
        "PackageKit::Transaction::UpdateState",
        "state",
        "issued",
        "updated",
        "failedFetchingDetails",
        "PackageKit::Transaction::Error",
        "msg",
        "dependencies",
        "QList<PackageKitDependency>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dependenciesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addPackageId'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Info, const QString &, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'setDetails'
        QtMocHelpers::SlotData<void(const PackageKit::Details &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'updateDetail'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &, const QStringList &, const QStringList &, const QStringList &, const QStringList &, PackageKit::Transaction::Restart, const QString &, const QString &, PackageKit::Transaction::UpdateState, const QDateTime &, const QDateTime &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QStringList, 13 }, { QMetaType::QStringList, 14 }, { QMetaType::QStringList, 15 },
            { QMetaType::QStringList, 16 }, { QMetaType::QStringList, 17 }, { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
            { QMetaType::QString, 21 }, { 0x80000000 | 22, 23 }, { QMetaType::QDateTime, 24 }, { QMetaType::QDateTime, 25 },
        }}),
        // Slot 'failedFetchingDetails'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Error, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 }, { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dependencies'
        QtMocHelpers::PropertyData<QList<PackageKitDependency>>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitResource, qt_meta_tag_ZN18PackageKitResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PackageKitResource::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractResource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PackageKitResourceE_t>.metaTypes,
    nullptr
} };

void PackageKitResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackageKitResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dependenciesChanged(); break;
        case 1: _t->addPackageId((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Info>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->setDetails((*reinterpret_cast<std::add_pointer_t<PackageKit::Details>>(_a[1]))); break;
        case 3: _t->updateDetail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Restart>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::UpdateState>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[12]))); break;
        case 4: _t->failedFetchingDetails((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Error>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Info >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Restart >(); break;
            case 9:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::UpdateState >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Error >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PackageKitResource::*)()>(_a, &PackageKitResource::dependenciesChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<PackageKitDependency>*>(_v) = _t->dependencies(); break;
        default: break;
        }
    }
}

const QMetaObject *PackageKitResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PackageKitResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PackageKitResourceE_t>.strings))
        return static_cast<void*>(this);
    return AbstractResource::qt_metacast(_clname);
}

int PackageKitResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractResource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PackageKitResource::dependenciesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
