/****************************************************************************
** Meta object code from reading C++ file 'Transaction.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/Transaction/Transaction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Transaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TransactionE_t {};
} // unnamed namespace

template <> constexpr inline auto Transaction::qt_create_metaobjectdata<qt_meta_tag_ZN11TransactionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Transaction",
        "statusChanged",
        "",
        "Transaction::Status",
        "status",
        "cancellableChanged",
        "cancellable",
        "progressChanged",
        "progress",
        "proceedRequest",
        "title",
        "description",
        "passiveMessage",
        "message",
        "distroErrorMessage",
        "visibleChanged",
        "visible",
        "downloadSpeedChanged",
        "downloadSpeed",
        "remainingTimeChanged",
        "remainingTime",
        "webflowStarted",
        "QUrl",
        "url",
        "id",
        "webflowDone",
        "cancel",
        "proceed",
        "name",
        "icon",
        "QVariant",
        "resource",
        "AbstractResource*",
        "role",
        "Role",
        "Status",
        "isCancellable",
        "downloadSpeedString",
        "remainingTimeString",
        "SetupStatus",
        "QueuedStatus",
        "DownloadingStatus",
        "CommittingStatus",
        "DoneStatus",
        "DoneWithErrorStatus",
        "CancelledStatus",
        "InstallRole",
        "RemoveRole",
        "ChangeAddonsRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Transaction::Status)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'cancellableChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'proceedRequest'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'distroErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'downloadSpeedChanged'
        QtMocHelpers::SignalData<void(quint64)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 18 },
        }}),
        // Signal 'remainingTimeChanged'
        QtMocHelpers::SignalData<void(uint)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
        // Signal 'webflowStarted'
        QtMocHelpers::SignalData<void(const QUrl &, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'webflowDone'
        QtMocHelpers::SignalData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Method 'cancel'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'proceed'
        QtMocHelpers::MethodData<void()>(27, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'icon'
        QtMocHelpers::PropertyData<QVariant>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'resource'
        QtMocHelpers::PropertyData<AbstractResource*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'role'
        QtMocHelpers::PropertyData<enum Role>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(4, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'isCancellable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'progress'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'downloadSpeed'
        QtMocHelpers::PropertyData<quint64>(18, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'downloadSpeedString'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'remainingTimeString'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'remainingTime'
        QtMocHelpers::PropertyData<uint>(20, QMetaType::UInt, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(35, 35, QMC::EnumFlags{}).add({
            {   39, Status::SetupStatus },
            {   40, Status::QueuedStatus },
            {   41, Status::DownloadingStatus },
            {   42, Status::CommittingStatus },
            {   43, Status::DoneStatus },
            {   44, Status::DoneWithErrorStatus },
            {   45, Status::CancelledStatus },
        }),
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(34, 34, QMC::EnumFlags{}).add({
            {   46, Role::InstallRole },
            {   47, Role::RemoveRole },
            {   48, Role::ChangeAddonsRole },
        }),
    };
    return QtMocHelpers::metaObjectData<Transaction, qt_meta_tag_ZN11TransactionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Transaction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TransactionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TransactionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TransactionE_t>.metaTypes,
    nullptr
} };

void Transaction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Transaction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Transaction::Status>>(_a[1]))); break;
        case 1: _t->cancellableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->proceedRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->distroErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->downloadSpeedChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 8: _t->remainingTimeChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 9: _t->webflowStarted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->webflowDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->cancel(); break;
        case 12: _t->proceed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(Transaction::Status )>(_a, &Transaction::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(bool )>(_a, &Transaction::cancellableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(int )>(_a, &Transaction::progressChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(const QString & , const QString & )>(_a, &Transaction::proceedRequest, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(const QString & )>(_a, &Transaction::passiveMessage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(const QString & )>(_a, &Transaction::distroErrorMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(bool )>(_a, &Transaction::visibleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(quint64 )>(_a, &Transaction::downloadSpeedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(uint )>(_a, &Transaction::remainingTimeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(const QUrl & , int )>(_a, &Transaction::webflowStarted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Transaction::*)(int )>(_a, &Transaction::webflowDone, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->icon(); break;
        case 2: *reinterpret_cast<AbstractResource**>(_v) = _t->resource(); break;
        case 3: *reinterpret_cast<enum Role*>(_v) = _t->role(); break;
        case 4: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isCancellable(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->progress(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 8: *reinterpret_cast<quint64*>(_v) = _t->downloadSpeed(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->downloadSpeedString(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->remainingTimeString(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->remainingTime(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 7: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setDownloadSpeed(*reinterpret_cast<quint64*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Transaction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Transaction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TransactionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Transaction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Transaction::statusChanged(Transaction::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Transaction::cancellableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Transaction::progressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Transaction::proceedRequest(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Transaction::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Transaction::distroErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Transaction::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Transaction::downloadSpeedChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Transaction::remainingTimeChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Transaction::webflowStarted(const QUrl & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Transaction::webflowDone(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
