/****************************************************************************
** Meta object code from reading C++ file 'PackageKitUpdater.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/PackageKitBackend/PackageKitUpdater.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PackageKitUpdater.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PackageKitUpdaterE_t {};
} // unnamed namespace

template <> constexpr inline auto PackageKitUpdater::qt_create_metaobjectdata<qt_meta_tag_ZN17PackageKitUpdaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PackageKitUpdater",
        "cancel",
        "",
        "start",
        "errorFound",
        "PackageKit::Transaction::Error",
        "err",
        "error",
        "mediaChange",
        "PackageKit::Transaction::MediaType",
        "media",
        "type",
        "text",
        "eulaRequired",
        "eulaID",
        "packageID",
        "vendor",
        "licenseAgreement",
        "finished",
        "PackageKit::Transaction::Exit",
        "exit",
        "cancellableChanged",
        "percentageChanged",
        "updateDetail",
        "updates",
        "obsoletes",
        "vendorUrls",
        "bugzillaUrls",
        "cveUrls",
        "PackageKit::Transaction::Restart",
        "restart",
        "updateText",
        "changelog",
        "PackageKit::Transaction::UpdateState",
        "state",
        "issued",
        "updated",
        "packageResolved",
        "PackageKit::Transaction::Info",
        "info",
        "packageId",
        "repoSignatureRequired",
        "repoName",
        "keyUrl",
        "keyUserid",
        "keyId",
        "keyFingerprint",
        "keyTimestamp",
        "PackageKit::Transaction::SigType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'errorFound'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Error, const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'mediaChange'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::MediaType, const QString &, const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'eulaRequired'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'finished'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Exit, uint)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::UInt, 2 },
        }}),
        // Slot 'cancellableChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'percentageChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDetail'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &, const QStringList &, const QStringList &, const QStringList &, const QStringList &, PackageKit::Transaction::Restart, const QString &, const QString &, PackageKit::Transaction::UpdateState, const QDateTime &, const QDateTime &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QStringList, 24 }, { QMetaType::QStringList, 25 }, { QMetaType::QStringList, 26 },
            { QMetaType::QStringList, 27 }, { QMetaType::QStringList, 28 }, { 0x80000000 | 29, 30 }, { QMetaType::QString, 31 },
            { QMetaType::QString, 32 }, { 0x80000000 | 33, 34 }, { QMetaType::QDateTime, 35 }, { QMetaType::QDateTime, 36 },
        }}),
        // Slot 'packageResolved'
        QtMocHelpers::SlotData<void(PackageKit::Transaction::Info, const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 },
        }}),
        // Slot 'repoSignatureRequired'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, PackageKit::Transaction::SigType)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 42 }, { QMetaType::QString, 43 }, { QMetaType::QString, 44 },
            { QMetaType::QString, 45 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { 0x80000000 | 48, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackageKitUpdater, qt_meta_tag_ZN17PackageKitUpdaterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PackageKitUpdater::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBackendUpdater::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PackageKitUpdaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PackageKitUpdaterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PackageKitUpdaterE_t>.metaTypes,
    nullptr
} };

void PackageKitUpdater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackageKitUpdater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancel(); break;
        case 1: _t->start(); break;
        case 2: _t->errorFound((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Error>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->mediaChange((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::MediaType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->eulaRequired((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 5: _t->finished((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Exit>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 6: _t->cancellableChanged(); break;
        case 7: _t->percentageChanged(); break;
        case 8: _t->updateDetail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Restart>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::UpdateState>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[12]))); break;
        case 9: _t->packageResolved((*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::Info>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->repoSignatureRequired((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<PackageKit::Transaction::SigType>>(_a[8]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Error >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::MediaType >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Exit >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Restart >(); break;
            case 9:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::UpdateState >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::Info >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 7:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PackageKit::Transaction::SigType >(); break;
            }
            break;
        }
    }
}

const QMetaObject *PackageKitUpdater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PackageKitUpdater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PackageKitUpdaterE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBackendUpdater::qt_metacast(_clname);
}

int PackageKitUpdater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBackendUpdater::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
