/****************************************************************************
** Meta object code from reading C++ file 'AbstractResourcesBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/resources/AbstractResourcesBackend.h"
#include "ReviewsBackend/AbstractReviewsBackend.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractResourcesBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ResultsStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto ResultsStream::qt_create_metaobjectdata<qt_meta_tag_ZN13ResultsStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResultsStream",
        "resourcesFound",
        "",
        "QList<StreamResult>",
        "resources",
        "fetchMore"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resourcesFound'
        QtMocHelpers::SignalData<void(const QVector<StreamResult> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fetchMore'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResultsStream, qt_meta_tag_ZN13ResultsStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResultsStream::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ResultsStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ResultsStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ResultsStreamE_t>.metaTypes,
    nullptr
} };

void ResultsStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResultsStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resourcesFound((*reinterpret_cast<std::add_pointer_t<QList<StreamResult>>>(_a[1]))); break;
        case 1: _t->fetchMore(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResultsStream::*)(const QVector<StreamResult> & )>(_a, &ResultsStream::resourcesFound, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultsStream::*)()>(_a, &ResultsStream::fetchMore, 1))
            return;
    }
}

const QMetaObject *ResultsStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResultsStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ResultsStreamE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ResultsStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ResultsStream::resourcesFound(const QVector<StreamResult> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ResultsStream::fetchMore()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN13InlineMessageE_t {};
} // unnamed namespace

template <> constexpr inline auto InlineMessage::qt_create_metaobjectdata<qt_meta_tag_ZN13InlineMessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InlineMessage",
        "type",
        "InlineMessageType",
        "iconName",
        "message",
        "actions",
        "QVariantList",
        "Information",
        "Positive",
        "Warning",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum InlineMessageType>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'actions'
        QtMocHelpers::PropertyData<QVariantList>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'InlineMessageType'
        QtMocHelpers::EnumData<enum InlineMessageType>(2, 2, QMC::EnumFlags{}).add({
            {    7, InlineMessageType::Information },
            {    8, InlineMessageType::Positive },
            {    9, InlineMessageType::Warning },
            {   10, InlineMessageType::Error },
        }),
    };
    return QtMocHelpers::metaObjectData<InlineMessage, qt_meta_tag_ZN13InlineMessageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InlineMessage::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13InlineMessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13InlineMessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13InlineMessageE_t>.metaTypes,
    nullptr
} };

void InlineMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InlineMessage *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum InlineMessageType*>(_v) = _t->type; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->iconName; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->message; break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->actions; break;
        default: break;
        }
    }
}

const QMetaObject *InlineMessage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InlineMessage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13InlineMessageE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InlineMessage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN24AbstractResourcesBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractResourcesBackend::qt_create_metaobjectdata<qt_meta_tag_ZN24AbstractResourcesBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractResourcesBackend",
        "contentsChanged",
        "",
        "updatesCountChanged",
        "allDataChanged",
        "QList<QByteArray>",
        "propertyNames",
        "resourcesChanged",
        "AbstractResource*",
        "resource",
        "properties",
        "resourceRemoved",
        "passiveMessage",
        "message",
        "inlineMessageChanged",
        "QSharedPointer<InlineMessage>",
        "inlineMessage",
        "fetchingUpdatesProgressChanged",
        "invalidated",
        "installApplication",
        "Transaction*",
        "app",
        "AddonList",
        "addons",
        "removeApplication",
        "checkForUpdates",
        "explainDysfunction",
        "InlineMessage*",
        "name",
        "displayName",
        "reviewsBackend",
        "AbstractReviewsBackend*",
        "updatesCount",
        "fetchingUpdatesProgress",
        "hasSecurityUpdates",
        "hasApplications"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contentsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatesCountChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allDataChanged'
        QtMocHelpers::SignalData<void(const QVector<QByteArray> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'resourcesChanged'
        QtMocHelpers::SignalData<void(AbstractResource *, const QVector<QByteArray> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 5, 10 },
        }}),
        // Signal 'resourceRemoved'
        QtMocHelpers::SignalData<void(AbstractResource *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'inlineMessageChanged'
        QtMocHelpers::SignalData<void(const QSharedPointer<InlineMessage> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'fetchingUpdatesProgressChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invalidated'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'installApplication'
        QtMocHelpers::SlotData<Transaction *(AbstractResource *, const AddonList &)>(19, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 8, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'installApplication'
        QtMocHelpers::SlotData<Transaction *(AbstractResource *)>(19, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 8, 21 },
        }}),
        // Slot 'removeApplication'
        QtMocHelpers::SlotData<Transaction *(AbstractResource *)>(24, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 8, 21 },
        }}),
        // Slot 'checkForUpdates'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'explainDysfunction'
        QtMocHelpers::SlotData<InlineMessage *() const>(26, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 27),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reviewsBackend'
        QtMocHelpers::PropertyData<AbstractReviewsBackend*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'updatesCount'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'fetchingUpdatesProgress'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
        // property 'hasSecurityUpdates'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'hasApplications'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractResourcesBackend, qt_meta_tag_ZN24AbstractResourcesBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractResourcesBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24AbstractResourcesBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24AbstractResourcesBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24AbstractResourcesBackendE_t>.metaTypes,
    nullptr
} };

void AbstractResourcesBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractResourcesBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contentsChanged(); break;
        case 1: _t->updatesCountChanged(); break;
        case 2: _t->allDataChanged((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1]))); break;
        case 3: _t->resourcesChanged((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 4: _t->resourceRemoved((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1]))); break;
        case 5: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->inlineMessageChanged((*reinterpret_cast<std::add_pointer_t<QSharedPointer<InlineMessage>>>(_a[1]))); break;
        case 7: _t->fetchingUpdatesProgressChanged(); break;
        case 8: _t->invalidated(); break;
        case 9: { Transaction* _r = _t->installApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AddonList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Transaction**>(_a[0]) = std::move(_r); }  break;
        case 10: { Transaction* _r = _t->installApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Transaction**>(_a[0]) = std::move(_r); }  break;
        case 11: { Transaction* _r = _t->removeApplication((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Transaction**>(_a[0]) = std::move(_r); }  break;
        case 12: _t->checkForUpdates(); break;
        case 13: { InlineMessage* _r = _t->explainDysfunction();
            if (_a[0]) *reinterpret_cast<InlineMessage**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<InlineMessage> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractResource* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)()>(_a, &AbstractResourcesBackend::contentsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)()>(_a, &AbstractResourcesBackend::updatesCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)(const QVector<QByteArray> & )>(_a, &AbstractResourcesBackend::allDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)(AbstractResource * , const QVector<QByteArray> & )>(_a, &AbstractResourcesBackend::resourcesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)(AbstractResource * )>(_a, &AbstractResourcesBackend::resourceRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)(const QString & )>(_a, &AbstractResourcesBackend::passiveMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)(const QSharedPointer<InlineMessage> & )>(_a, &AbstractResourcesBackend::inlineMessageChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)()>(_a, &AbstractResourcesBackend::fetchingUpdatesProgressChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractResourcesBackend::*)()>(_a, &AbstractResourcesBackend::invalidated, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 2: *reinterpret_cast<AbstractReviewsBackend**>(_v) = _t->reviewsBackend(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->updatesCount(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->fetchingUpdatesProgress(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasSecurityUpdates(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasApplications(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractResourcesBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractResourcesBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24AbstractResourcesBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractResourcesBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void AbstractResourcesBackend::contentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractResourcesBackend::updatesCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractResourcesBackend::allDataChanged(const QVector<QByteArray> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractResourcesBackend::resourcesChanged(AbstractResource * _t1, const QVector<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void AbstractResourcesBackend::resourceRemoved(AbstractResource * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractResourcesBackend::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AbstractResourcesBackend::inlineMessageChanged(const QSharedPointer<InlineMessage> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AbstractResourcesBackend::fetchingUpdatesProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AbstractResourcesBackend::invalidated()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
namespace {
struct qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractResourcesBackendFactory::qt_create_metaobjectdata<qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractResourcesBackendFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractResourcesBackendFactory, qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractResourcesBackendFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>.metaTypes,
    nullptr
} };

void AbstractResourcesBackendFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractResourcesBackendFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *AbstractResourcesBackendFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractResourcesBackendFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31AbstractResourcesBackendFactoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractResourcesBackendFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
