/****************************************************************************
** Meta object code from reading C++ file 'FlatpakTransactionThread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/FlatpakBackend/FlatpakTransactionThread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FlatpakTransactionThread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24FlatpakTransactionThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakTransactionThread::qt_create_metaobjectdata<qt_meta_tag_ZN24FlatpakTransactionThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakTransactionThread",
        "progressChanged",
        "",
        "progress",
        "speedChanged",
        "speed",
        "passiveMessage",
        "msg",
        "webflowStarted",
        "QUrl",
        "url",
        "id",
        "webflowDone",
        "finished",
        "cancelled",
        "errorMessage",
        "FlatpakTransactionThread::Repositories",
        "addedRepositories",
        "success",
        "proceedRequest",
        "title",
        "description",
        "statusChanged",
        "Transaction::Status",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'speedChanged'
        QtMocHelpers::SignalData<void(quint64)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
        // Signal 'passiveMessage'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'webflowStarted'
        QtMocHelpers::SignalData<void(const QUrl &, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'webflowDone'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bool, const QString &, const FlatpakTransactionThread::Repositories &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 }, { QMetaType::QString, 15 }, { 0x80000000 | 16, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'proceedRequest'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Transaction::Status)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FlatpakTransactionThread, qt_meta_tag_ZN24FlatpakTransactionThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakTransactionThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FlatpakTransactionThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FlatpakTransactionThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24FlatpakTransactionThreadE_t>.metaTypes,
    nullptr
} };

void FlatpakTransactionThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlatpakTransactionThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->speedChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 2: _t->passiveMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->webflowStarted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->webflowDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->finished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FlatpakTransactionThread::Repositories>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 6: _t->proceedRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Transaction::Status>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(int )>(_a, &FlatpakTransactionThread::progressChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(quint64 )>(_a, &FlatpakTransactionThread::speedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(const QString & )>(_a, &FlatpakTransactionThread::passiveMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(const QUrl & , int )>(_a, &FlatpakTransactionThread::webflowStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(int )>(_a, &FlatpakTransactionThread::webflowDone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(bool , const QString & , const FlatpakTransactionThread::Repositories & , bool )>(_a, &FlatpakTransactionThread::finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(const QString & , const QString & )>(_a, &FlatpakTransactionThread::proceedRequest, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakTransactionThread::*)(Transaction::Status )>(_a, &FlatpakTransactionThread::statusChanged, 7))
            return;
    }
}

const QMetaObject *FlatpakTransactionThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlatpakTransactionThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FlatpakTransactionThreadE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QRunnable"))
        return static_cast< QRunnable*>(this);
    return QObject::qt_metacast(_clname);
}

int FlatpakTransactionThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void FlatpakTransactionThread::progressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FlatpakTransactionThread::speedChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FlatpakTransactionThread::passiveMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FlatpakTransactionThread::webflowStarted(const QUrl & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void FlatpakTransactionThread::webflowDone(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void FlatpakTransactionThread::finished(bool _t1, const QString & _t2, const FlatpakTransactionThread::Repositories & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 6
void FlatpakTransactionThread::proceedRequest(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void FlatpakTransactionThread::statusChanged(Transaction::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
