/*
 *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 *
 *   SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef DISCOVERVERSION_H
#define DISCOVERVERSION_H

#include <QLatin1String>

static QLatin1String version("6.7.3");

#endif
