/****************************************************************************
** Meta object code from reading C++ file 'KNSBackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../discover-6.7.3/libdiscover/backends/KNSBackend/KNSBackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KNSBackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KNSBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KNSBackend::qt_create_metaobjectdata<qt_meta_tag_ZN10KNSBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KNSBackend",
        "initialized",
        "",
        "statusChanged",
        "KNSCore::Entry",
        "entry",
        "detailsLoaded",
        "slotErrorCode",
        "KNSCore::ErrorCode::ErrorCode",
        "errorCode",
        "message",
        "QVariant",
        "metadata",
        "slotEntryEvent",
        "KNSCore::Entry::EntryEvent",
        "event"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initialized'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'statusChanged'
        QtMocHelpers::SlotData<void(const KNSCore::Entry &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'detailsLoaded'
        QtMocHelpers::SlotData<void(const KNSCore::Entry &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotErrorCode'
        QtMocHelpers::SlotData<void(const KNSCore::ErrorCode::ErrorCode &, const QString &, const QVariant &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotEntryEvent'
        QtMocHelpers::SlotData<void(const KNSCore::Entry &, KNSCore::Entry::EntryEvent)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KNSBackend, qt_meta_tag_ZN10KNSBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KNSBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractResourcesBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KNSBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KNSBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KNSBackendE_t>.metaTypes,
    nullptr
} };

void KNSBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KNSBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initialized(); break;
        case 1: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1]))); break;
        case 2: _t->detailsLoaded((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1]))); break;
        case 3: _t->slotErrorCode((*reinterpret_cast<std::add_pointer_t<KNSCore::ErrorCode::ErrorCode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 4: _t->slotEntryEvent((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KNSCore::Entry::EntryEvent>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KNSBackend::*)()>(_a, &KNSBackend::initialized, 0))
            return;
    }
}

const QMetaObject *KNSBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNSBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KNSBackendE_t>.strings))
        return static_cast<void*>(this);
    return AbstractResourcesBackend::qt_metacast(_clname);
}

int KNSBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractResourcesBackend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KNSBackend::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
