/****************************************************************************
** Meta object code from reading C++ file 'TransactionModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../discover-6.7.3/libdiscover/Transaction/TransactionModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TransactionModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TransactionModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TransactionModel::qt_create_metaobjectdata<qt_meta_tag_ZN16TransactionModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransactionModel",
        "startingFirstTransaction",
        "",
        "lastTransactionFinished",
        "transactionAdded",
        "Transaction*",
        "transaction",
        "transactionRemoved",
        "countChanged",
        "progressChanged",
        "proceedRequest",
        "title",
        "description",
        "mainTransactionTextChanged",
        "transactionFromResource",
        "AbstractResource*",
        "resource",
        "progress",
        "count",
        "mainTransactionText",
        "Roles",
        "TransactionRoleRole",
        "TransactionStatusRole",
        "CancellableRole",
        "ProgressRole",
        "StatusTextRole",
        "ResourceRole",
        "TransactionRole",
        "VisibleRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startingFirstTransaction'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastTransactionFinished'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transactionAdded'
        QtMocHelpers::SignalData<void(Transaction *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'transactionRemoved'
        QtMocHelpers::SignalData<void(Transaction *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proceedRequest'
        QtMocHelpers::SignalData<void(Transaction *, const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'mainTransactionTextChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'transactionFromResource'
        QtMocHelpers::MethodData<Transaction *(AbstractResource *) const>(14, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 5, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'progress'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'count'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'mainTransactionText'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(20, 20, QMC::EnumFlags{}).add({
            {   21, Roles::TransactionRoleRole },
            {   22, Roles::TransactionStatusRole },
            {   23, Roles::CancellableRole },
            {   24, Roles::ProgressRole },
            {   25, Roles::StatusTextRole },
            {   26, Roles::ResourceRole },
            {   27, Roles::TransactionRole },
            {   28, Roles::VisibleRole },
        }),
    };
    return QtMocHelpers::metaObjectData<TransactionModel, qt_meta_tag_ZN16TransactionModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransactionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TransactionModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TransactionModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TransactionModelE_t>.metaTypes,
    nullptr
} };

void TransactionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransactionModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startingFirstTransaction(); break;
        case 1: _t->lastTransactionFinished(); break;
        case 2: _t->transactionAdded((*reinterpret_cast<std::add_pointer_t<Transaction*>>(_a[1]))); break;
        case 3: _t->transactionRemoved((*reinterpret_cast<std::add_pointer_t<Transaction*>>(_a[1]))); break;
        case 4: _t->countChanged(); break;
        case 5: _t->progressChanged(); break;
        case 6: _t->proceedRequest((*reinterpret_cast<std::add_pointer_t<Transaction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->mainTransactionTextChanged(); break;
        case 8: { Transaction* _r = _t->transactionFromResource((*reinterpret_cast<std::add_pointer_t<AbstractResource*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Transaction**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transaction* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transaction* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transaction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)()>(_a, &TransactionModel::startingFirstTransaction, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)()>(_a, &TransactionModel::lastTransactionFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)(Transaction * )>(_a, &TransactionModel::transactionAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)(Transaction * )>(_a, &TransactionModel::transactionRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)()>(_a, &TransactionModel::countChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)()>(_a, &TransactionModel::progressChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)(Transaction * , const QString & , const QString & )>(_a, &TransactionModel::proceedRequest, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransactionModel::*)()>(_a, &TransactionModel::mainTransactionTextChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->progress(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->mainTransactionText(); break;
        default: break;
        }
    }
}

const QMetaObject *TransactionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransactionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TransactionModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int TransactionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void TransactionModel::startingFirstTransaction()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TransactionModel::lastTransactionFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TransactionModel::transactionAdded(Transaction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TransactionModel::transactionRemoved(Transaction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TransactionModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TransactionModel::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TransactionModel::proceedRequest(Transaction * _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void TransactionModel::mainTransactionTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
